@@ -10,7 +10,7 @@
 
 # Merge the public interface of all submodules.
 __all__ = []
-for module in ['leads', 'dispersion']:
+for module in ['leads', 'dispersion', 'noise']:
     exec 'from . import {0}'.format(module)
     exec 'from .{0} import *'.format(module)
     exec '__all__.extend({0}.__all__)'.format(module)
